from ..base import AdyenServiceBase


class GrantAccountsApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(GrantAccountsApi, self).__init__(client=client)
        self.service = "balancePlatform"

    def get_grant_account(self, id, idempotency_key=None, **kwargs):
        """
        Get a grant account
        """
        endpoint = f"/grantAccounts/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

